clear all
version 12
set more off

do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

cd "$data"
use finaldata.dta, clear

lab var st_expgt3i "Sibling teacher*Teacher experience >= 3 years"
lab var st_more_than_BA "Sibling teacher*Teacher has advanced degree"
lab var st_nbpts "Sibling teacher*Teacher is National Board certified"
lab var any_ostchp_va "Sibling teacher*Teacher value-added"

display c(current_time)

quie do "$do_files/Jaselyn/tchsrt/cr_rr_tables/Tab56_BootstrapProgram.do"

**Table 5
global controls propst eds preread_ltm Black Hispanic Other st_eds st_preread_ltm st_Black st_Hispanic st_Other

areg atch any_ostchp expgt3i st_expgt3i $controls , absorb(schgryrst) cluster(my)
est store t5a

areg atch any_ostchp more_than_BA st_more_than_BA $controls , absorb(schgryrst) cluster(my)
est store t5b

areg atch any_ostchp nbpts st_nbpts $controls , absorb(schgryrst) cluster(my)
est store t5c

global regvars any_ostchp  
boot_sib, spec(quie _regress atch va any_ostchp_va $regvars $controls, absorb(schgryrst)) savecoef(va any_ostchp_va $controls) va_int(any_ostchp) n($max_iter) eststo_name(t5d)

global regvars any_ostchp expgt3i more_than_BA nbpts st_expgt3i st_more_than_BA st_nbpts
boot_sib, spec(quie _regress atch va any_ostchp_va $regvars $controls, absorb(schgryrst)) savecoef(va any_ostchp_va expgt3i more_than_BA nbpts st_expgt3i st_more_than_BA st_nbpts $controls) va_int(any_ostchp) n($max_iter) eststo_name(t5e)

cd "$tables"
xml_tab t5a t5b t5c, ///
save("Final_RR_Tables.xml") sheet("Table 5") title("Table 5: Heterogeneity in Sorting to Sibling Teachers by Teacher Characteristics") append ///
font("garamond") stats(N) below keep(st_expgt3i st_more_than_BA st_nbpts) ///
note("Note: *** p < 0.01, ** p < 0.05, * p < 0.10. All regressions control for student characteristics (race/ethnicity indicators, student poverty, and low achieving indicator), the proportion of students taught by the teacher, and sibling-teacher-by-school-grade-year fixed effects. Each of the regressions in Columns 1-4 also includes the main effect of the relevant teacher characteristic and Column 5 includes all teacher characteristics and their interactions with the sibling teacher indicator simultaneously. Standard errors are clustered at the student-year level for columns (1) - (3), while standard errors in columns (4) and (5) which include value-added controls are calculated via bootstrap as described in the text.")

estout t5d t5e using "$tables/Final_RR_Tables.txt", append label cells(b(fmt(4)) seboot(fmt(4))) stats(N) keep(st_expgt3i st_more_than_BA st_nbpts any_ostchp_va) title("Table 5: Heterogeneity in Sorting to Sibling Teachers by Teacher Characteristics")

/*
Bootstrapped regressions must have significance assessed manually, and stars must also be added manually.
*/


