clear all
version 12
set more off

do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

cd "$data"
use finaldata.dta, clear

display c(current_time)

**Table 7
replace rgain_fs = st_rgain_fs
replace multiyrs_ptch = st_multiyrs_ptch
replace long_time = st_long_time

foreach var in expgt3i more_than_BA nbpts va {
	gen Bl_`var' = Black*`var'
	gen His_`var' = Hispanic*`var'
	gen Oth_`var' = Other*`var'
}

lab var rgain_fs "Sibling test score gain"
lab var multiyrs_ptch "Sibling had teacher multiple times"
lab var long_time "Sibling had teacher more than 2 years ago"
lab var st_scoregap "Sibling teacher*Gap in siblings' lagged test scores"
lab var black_int "Student is Black*Teacher is Black"
lab var st_black_int "Sibling teacher*Student is Black*Teacher is Black"

global controls propst preread_ltm agegap_fs Black st_preread_ltm st_agegap_fs st_Black expgt3i more_than_BA nbpts va eds_expgt3i eds_more_than_BA eds_nbpts eds_va nw_expgt3i nw_more_than_BA nw_nbpts nw_va la_expgt3i la_more_than_BA la_nbpts preread_ltm_va

areg atch any_ostchp rgain_fs lagscore_fs st_lagscore_fs $controls, absorb(schgryrst) robust
est store t7a

areg atch any_ostchp multiyrs_ptch $controls, absorb(schgryrst) robust
est store t7b 

areg atch any_ostchp long_time $controls, absorb(schgryrst) robust
est store t7c

areg atch any_ostchp scoregap st_scoregap $controls, absorb(schgryrst) robust
est store t7d


global controls propst preread_ltm agegap_fs Black Hispanic Other st_preread_ltm st_agegap_fs st_Black st_Hispanic st_Other expgt3i more_than_BA nbpts va eds_expgt3i eds_more_than_BA eds_nbpts eds_va Bl_expgt3i Bl_more_than_BA Bl_nbpts Bl_va His_expgt3i His_more_than_BA His_nbpts His_va Oth_expgt3i Oth_more_than_BA Oth_nbpts Oth_va la_expgt3i la_more_than_BA la_nbpts preread_ltm_va
areg atch any_ostchp tch_rblack st_tch_rblack black_int st_black_int $controls, absorb(schgryrst) robust
est store t7e

cd "$tables"
xml_tab t7a t7b t7c t7d t7e, ///
save("Final_RR_Tables.xml") sheet("Table 7") title("Table 7: The Role of Additional Factors in Predicting Sibling Teacher Assignment") keep(rgain_fs multiyrs_ptch long_time st_scoregap black_int st_black_int) ///
font("garamond") append stats(N)  below ///
note("Note: *** p < 0.01, ** p < 0.05, * p < 0.10. All regressions control for the proportion of students taught by the teacher, student characteristics, teacher characteristics, the interactions of teacher and student characteristics, the age gap between siblings, its interaction with sibling teacher indicator, and sibling-teacher-by-school-grade-year fixed effects. Column 1 includes a measure of sibling's reading score gain with the sibling teacher, and controls for the sibling's lagged reading score. Column 2 includes an indicator equal to 1 if the sibling was taught by the sibling teacher multiple times and 0 otherwise. Column 3 includes an indicator equal to 1 if the sibling was taught by the sibling teacher more than 2 years ago. Column 4 includes a measure of the gap (absolute value of the difference) in the child's and sibling's lagged reading scores and its interaction with the sibling teacher indicator. Column 5 includes an interaction of the sibling teacher indicator and student is Black, an interaction of the sibling teacher indicator and teacher is Black, an interaction of student is Black and teacher is Black, and an interaction of the sibling teacher indicator, student is Black and teacher is Black. Standard errors are clustered at the student-year level.")

display c(current_time)

