clear all
version 13
set more off
do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"
set matsize 11000

cd "$data"
use VAMdata.dta, clear

keep if Age<12.23 & Age>9.21
keep if class_size<50 & class_size>10
label define middle 0 elementary 1 middle
label define math 0 "not math" 1 math
label define read 0 "not reading" 1 reading
label values middle_schl middle
label values math_subj math
label values read_subj read


gen self_contained = 1 if (math_subj==1 & read_subj==1)

**This code expands the self-contained classrooms to be 2 lines, 1 for reading and 1 for math.
expand 2

bys mastid year: replace math_subj=0 if self_contained==1 & _n==1
bys mastid year: replace read_subj=0 if self_contained==1 & _n==2

duplicates drop

gen math_and_read = math if math_subj==1
replace math_and_read = read if read_subj==1
		  
global simplecontrols eds Black White Hispanic Female Age preread premath lep_flag ///
                    disabled CL_Black ///
		    CL_White CL_Hispanic CL_Female CL_disabled CL_eds ///
		    CL_lep_flag CL_grade_repeat CL_premath CL_preread YRyear_2008-YRyear_2011 class_size_t

global bothsimplecontrols "c.preread#c.read_subj c.premath#c.math_subj c.CL_premath#c.math_subj c.CL_preread#c.read_subj "

quietly areg math_and_read $simplecontrols $bothsimplecontrols  , absorb(teachid)
gen samp3 = e(sample)
egen num_obs = total (samp3) , by(teachid)

keep if num_obs>10

reg math $simplecontrols $bothsimplecontrols  teachid if math_subj==1 & middle_schl==0 & grade!=3
g samp1 = (e(sample)==1)
reg read $simplecontrols $bothsimplecontrols  teachid if read_subj==1 & middle_schl==0 & grade!=3
g samp2 = (e(sample)==1)

keep if samp1 == 1 | samp2 == 1


forvalues i=0/$max_iter {


preserve
if `i' > 0 {
bsample, strata(teachid)
}



quietly areg math $simplecontrols if math_subj==1 , absorb(teachid)
predict math_tfe, d

qui areg math_and_read $simplecontrols $bothsimplecontrols  , absorb(teachid)
predict both_tfe, d

bys teachid: egen math_va = max(math_tfe)
bys teachid: egen both_va = max(both_tfe)

* CREATE tchr-level dataset of VA*
*************************************************************
collapse math_va  both_va num_obs, by(teachid)



foreach v in  math_va  both_va  {

egen sd_`v' = sd(`v')
egen m_`v' = mean(`v')

}


if `i' == 0 {

foreach v in  math_va  both_va  {

	replace `v' = (`v' - m_`v')/sd_`v'
	
	}
	keep teachid math_va  both_va num_obs
}

else {

	foreach v in  math_va  both_va  {

		gen `v'`i' = (`v' - m_`v')/sd_`v'
	
	}
	keep teachid math_va`i'  both_va`i' 

}




if `i'==0{
	cd "$data"
	save tchr_va_boot_total.dta,replace

rename teachid ptch
sort ptch
	
	save tchr_va_singleboot_total.dta,replace

}



if `i'>0 {
	merge 1:1 teachid using tchr_va_boot_total.dta , gen(merged_ok)
	drop merged_ok
	cd "$data"
	save tchr_va_boot_total.dta,replace
	dis " iteration `i' complete"
}

restore
}


use tchr_va_boot_total,clear
rename teachid ptch
sort ptch
save tchr_va_boot_total,replace



