clear all
version 12
set more off
cap log close
do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

/*This do-file now creates the sibling data: birth order, age gaps, sibling's teacher, etc. It does this for all students in the data set,
and then drops students who are not in 4th or 5th grade. This gives us the most complete information on students and their families.*/

cd "$data"
use readdata_rr.dta, clear

drop if dropclass1a == 1
drop dropclass1a dropclass1b


*STEP 1: Merge in sibling ID variable
*****************************************
cd "$rawfam"
merge m:1 mastid using sibling_pub.dta
drop if _merge==2
drop _merge

sort siblingID mastid grade year

egen kid = tag(siblingID mastid)
replace kid = . if kid == 0
bysort siblingID: egen family = count(kid)
label variable family "# kids in family with teacher ids in the the same subject grade"
tab family
gen mis_sibID = (siblingID == .)
replace family = . if siblingID == .

drop if family == 10
gen big_fam = (family > 2) if family !=.
label variable big_fam "more than two kids in the family"
gen sm_fam = (family == 1) if family !=.
lab var sm_fam "student is only child"
tab plurality twin
replace plurality = . if plurality == 9
*Create indicator that the family has any multiple birth and then drop those families 
gen any_tuple = (plurality>=2) if plurality != .
bys siblingID: egen anytuple = max(any_tuple)
drop any_tuple
tab anytuple
tab plurality anytuple

sort siblingID birthdt mastid year
*Identify sibling order
format birthdt %d
bys mastid: egen birthdtmx = max(birthdt)
bys mastid: egen birthdtmn = min(birthdt)
replace birthdt = birthdtmx
drop birthdtmx

bys siblingID: egen birthdtmax = max(birthdt) 
bys siblingID: egen birthdtmin = min(birthdt)
g sib1 = birthdt==birthdtmin

bys mastid: egen x_sib1 = max(sib1)
replace sib1 = x_sib1
drop x_sib1

replace sib1 = . if mis_sibID == 1

sort siblingID birthdt mastid year

*Creates indicators for which sibling we are looking at: sib1 is oldest, sib2 is second oldest, etc (Note: biggest family we kept has 9 kids)
forvalues k = 2/9 {
	local s = `k' - 1
	by siblingID: gen sib`k' = 1 if sib`s'[_n-1]==1 & mastid[_n]!=mastid[_n-1] & mis_sibID == 0
	by siblingID: replace sib`k' = 1 if sib`k'[_n-1]==1 & mastid[_n]==mastid[_n-1] & mis_sibID == 0
	by siblingID: replace sib`k' = 0 if sib`k'==. & mis_sibID == 0
	
	replace sib`k' = . if family < `k' & mis_sibID == 0
}

sort siblingID birthdt mastid year

/*
Only three families with 9 children have the ninth child in 4th or 5th grade during 2007-2012. For IRB compliance, we drop those families. The largest family now has 8 children. There are 7 such families in the data set and four of them have the youngest child in grades 4/5 during 2007-2012.
*/

drop if family == 9
drop sib9

*Create age gaps
*First generate birthdt of each sibling.
forvalues k = 1/8 {
	g birthdt_`k' = birthdt if sib`k' == 1
	by siblingID: egen birthdt`k' = max(birthdt_`k') if mis_sibID == 0
}

*Some students were assigned sib`s' == 1 & sib`k' == 1 because they are twins. Correct so only one is sib`s' and the other is sib`k'
forval k = 2/8 {
	local s = `k' - 1
	replace plurality = 2 if sib`s' == 1 & sib`k' == 1 & birthdt_`s' == birthdt_`k' & plurality == 1
	replace sib`s' = 0 if sib`s' == 1 & sib`k' == 1 & plurality > 1
}

drop birthdt_*


*Next subtract birthdts for each sibling. 
forvalues k = 1/7 {
	local s = `k' + 1
	by siblingID: g agegap_s`k's`s' = (birthdt`s' - birthdt`k')/365 if mis_sibID == 0
}

forvalues k = 1/6 {
	local s = `k' + 2
	by siblingID: g agegap_s`k's`s' = (birthdt`s' - birthdt`k')/365 if mis_sibID == 0
}

forvalues k = 1/5 {
	local s = `k' + 3
	by siblingID: g agegap_s`k's`s' = (birthdt`s' - birthdt`k')/365 if mis_sibID == 0
}

forvalues k = 1/4 {
	local s = `k' + 4
	by siblingID: g agegap_s`k's`s' = (birthdt`s' - birthdt`k')/365 if mis_sibID == 0
}

forvalues k = 1/3 {
	local s = `k' + 5
	by siblingID: g agegap_s`k's`s' = (birthdt`s' - birthdt`k')/365 if mis_sibID == 0
}

forvalues k = 1/2 {
	local s = `k' + 6
	by siblingID: g agegap_s`k's`s' = (birthdt`s' - birthdt`k')/365 if mis_sibID == 0
}

forvalues k = 1/1 {
	local s = `k' + 7
	by siblingID: g agegap_s`k's`s' = (birthdt`s' - birthdt`k')/365 if mis_sibID == 0
}

drop birthdt1 birthdt2 birthdt3 birthdt4 birthdt5 birthdt6 birthdt7 birthdt8

*Identify year in which each sib was in each grade: k is sibling, yr is year
forvalues k = 1/8 {
	forvalues yr = 2007/2012 {
		g grade_sib`k'_`yr' = grade if sib`k'==1 & mis_sibID == 0 & year == `yr'
	}
}

forvalues k = 1/8 {
	forvalues yr = 2007/2012 {
		foreach var in grade_sib`k'_`yr' {
			bys siblingID: egen `var'_m = max(`var') if mis_sibID == 0
			drop `var'
			rename `var'_m `var'
			dis "`var' not missing:"
			count if `var' != .
		}
	}
}

*Number of siblings observed in each grade; will be missing for only children
bys siblingID grade year: egen nsoi4g = count(mastid) if mis_sibID == 0 & grade == 4 & family > 1
lab var nsoi4g "Number of siblings in 4th grade"
bys siblingID grade year: egen nsoi5g = count(mastid) if mis_sibID == 0 & grade == 5 & family > 1
lab var nsoi5g "Number of siblings in 5th grade"

tab nsoi4g
tab nsoi4g anytuple
tab nsoi5g
tab nsoi5g anytuple


**indicators for same grade as younger siblings
gen in4gr_wsib = .
lab var in4gr_wsib "In 4th grade with a sibling"
gen in5gr_wsib = .
lab var in5gr_wsib "In 5th grade with a sibling"

local c = 7
local add = 1
while `c' > 0 {
	forval k = 1/`c' {
		forval yr = 2007/2012 {
			local s = `k' + `add'
			replace in4gr_wsib = 1 if grade_sib`k'_`yr' == grade_sib`s'_`yr' & grade_sib`k'_`yr' != . & grade_sib`s'_`yr' != . & sib`k'==1 & year == `yr' & grade == 4 & in4gr_wsib ==. & mis_sibID ==0 & family > 1
			replace in4gr_wsib = 1 if grade_sib`k'_`yr' == grade_sib`s'_`yr' & grade_sib`k'_`yr' != . & grade_sib`s'_`yr' != . & sib`s'==1 & year == `yr' & grade == 4 & in4gr_wsib ==. & mis_sibID ==0 & family > 1
			
			replace in5gr_wsib = 1 if grade_sib`k'_`yr' == grade_sib`s'_`yr' & grade_sib`k'_`yr' != . & grade_sib`s'_`yr' != . & sib`k'==1 & year == `yr' & grade == 5 & in5gr_wsib ==. & mis_sibID ==0 & family > 1
			replace in5gr_wsib = 1 if grade_sib`k'_`yr' == grade_sib`s'_`yr' & grade_sib`k'_`yr' != . & grade_sib`s'_`yr' != . & sib`s'==1 & year == `yr' & grade == 5 & in5gr_wsib ==. & mis_sibID ==0 & family > 1
		}
	}
	local add = `add' + 1
	local c = `c' - 1
}

replace in4gr_wsib = 0 if in4gr_wsib == . & family > 1
replace in5gr_wsib = 0 if in5gr_wsib == . & family > 1

*Fill in across grades
foreach var in nsoi4g nsoi5g {
	bys siblingID: egen m_`var' = max(`var')
	drop `var'
	rename m_`var' `var'
}

foreach var in in4gr_wsib in5gr_wsib {
	bys siblingID mastid: egen m_`var' = max(`var')
	drop `var'
	rename m_`var' `var'
}

display "Count for in4gr_wsib"
count if in4gr_wsib != .
display "Count for in5gr_wsib"
count if in5gr_wsib != . 

*Create variable for which teacher a student had in each year*
forval k = 1/8 {
	forval yr = 2007/2012 {
		gen sib`k'_tch`yr' = teachid if sib`k' == 1 & year == `yr' & teachid !=.
		bys siblingID: egen x_sib`k'_tch`yr' = max(sib`k'_tch`yr')
		drop sib`k'_tch`yr'
		rename x_sib`k'_tch`yr' sib`k'_tch`yr'
	}
}

*Create variable for siblings' reading score, lagged reading score, and reading gain
forval k = 1/8 {
	forval yr = 2007/2012 {
		display "Sibling `k' Reading Score in `yr'"
		gen sib`k'_read`yr' = read if sib`k' == 1 & year == `yr' & read !=.
		bys siblingID: egen x_sib`k'_read`yr' = max(sib`k'_read`yr')
		drop sib`k'_read`yr'
		rename x_sib`k'_read`yr' sib`k'_read`yr'
		
		display "Sibling `k' Lagged Reading Score in `yr'"
		gen sib`k'_preread`yr' = preread if sib`k' == 1 & year == `yr' & preread !=.
		bys siblingID: egen x_sib`k'_preread`yr' = max(sib`k'_preread`yr')
		drop sib`k'_preread`yr'
		rename x_sib`k'_preread`yr' sib`k'_preread`yr'
		
		display "Sibling `k' Reading Score Gain in `yr'"
		gen sib`k'_rgain`yr' = read - preread if sib`k' == 1 & year == `yr' & read !=. & preread !=.
		bys siblingID: egen x_sib`k'_rgain`yr' = max(sib`k'_rgain`yr')
		drop sib`k'_rgain`yr'
		rename x_sib`k'_rgain`yr' sib`k'_rgain`yr'
	}
}

keep if grade == 4 | grade == 5

**Create indicator for older sibling teacher info missing**
egen kid_new = tag(siblingID mastid)
replace kid_new = . if kid_new == 0

egen family_withinfo = total(kid_new)
replace family_withinfo = 1 if family == 1

gen miss_osib_info =  1 if family != family_withinfo & sib1 != 1 & family == 2
replace miss_osib_info = 1 if family != family_withinfo & sib1 != 1 & sib2 != 1 & family == 3
replace miss_osib_info = 1 if family != family_withinfo & sib1 != 1 & sib2 != 1 & sib3 != 1 & family == 4
replace miss_osib_info = 1 if family != family_withinfo & sib1 != 1 & sib2 != 1 & sib3 != 1 & sib4 != 1 & family == 5
replace miss_osib_info = 1 if family != family_withinfo & sib1 != 1 & sib2 != 1 & sib3 != 1 & sib4 != 1 & sib5 != 1 & family == 6
replace miss_osib_info = 1 if family != family_withinfo & sib1 != 1 & sib2 != 1 & sib3 != 1 & sib4 != 1 & sib5 != 1 & sib6 != 1 & family == 7
replace miss_osib_info = 1 if family != family_withinfo & sib1 != 1 & sib2 != 1 & sib3 != 1 & sib4 != 1 & sib5 != 1 & sib6 != 1 & sib8 != 1 & family == 8
replace miss_osib_info = 0 if miss_osib_info == .

bys siblingID: egen x_mosi = max(miss_osib_info)
replace miss_osib_info = x_mosi
drop x_mosi

lab var miss_osib_info "Missing teacher info on older siblings"
drop family_withinfo

cd "$data"
save data_rr_1a.dta, replace 
