clear all
version 12
set more off
cap log close

do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

display c(current_time)

/*This do-file cleans the panel data which is student-by-school-by-grade-by-year-by-potential-teacher.*/

cd "$data"
use panel1_rr_1a.dta, clear

**Drop unneeded variables**
drop st_sgy _merge grdrp

***Verify that data is student-by-school-by-grade-by-year-by-potential-teacher***
egen key = group(lea_r schlcode_fl grade year mastid ptch)
duplicates report key
drop key

***Create teacher indicator variables***
gen atch = (teachid == ptch)
lab var atch "Potential teacher is student's actual teacher"

forval k = 1/8 {
	forval yr = 2007/2012 {
		gen sib`k'_atch`yr' = (sib`k'_tch`yr' == ptch) if mis_sibID == 0 & family > 1
		*bys siblingID: egen x_sib`k'_atch`t' = max(sib`k'_atch`t')
		*drop sib`k'_atch`t'
		*rename x_sib`k'_atch`t' sib`k'_atch`t'
		replace sib`k'_atch`yr' = . if family < `k'
		lab var sib`k'_atch`yr' "Potential teacher is sib`k''s tchr in `yr'"
	}
}

order lea_r schlcode_fl year grade mastid siblingID ptch atch sib1_atch* sib2_a* sib3_a* sib4_a* sib5_a* sib6_a* sib7_a* sib8_a*, first

**Create anymatch indicators**
gen byte any_match = .
lab var any_match "YS and OS had this teacher in the past"

local c = 2
while `c' < 9 {
	local diff = 1
	forval k = `c'/8 {
		local s = `k' - `diff'
		display "Older sib: `s'"
		display "Current sib: `k'"
		forval yr = 2007/2012  {
			display "Year: `yr'"
			replace any_match = 1 if ptch == sib`s'_tch`yr' & sib`k'==1 & atch == 1 & year > `yr'
			}
		local diff = `diff' + 1
	}
	local c = `c' + 1
}

replace any_match = 0 if any_match == .

tab any_match

gen any_ostchp = .
gen lasthad_osp = ""
gen lasthad_yrp =.
gen lasthad_grp = .
gen lasthad_sincep =.
local c = 2
while `c' < 9 {
	local diff = 1
	forval k = `c'/8 {
		local s = `k' - `diff'
		display "Older sib: `s'"
		display "Current sib: `k'"
		forval yr = 2007/2012  {
			display "Year: `yr'"
			replace any_ostchp = 1 if ptch == sib`s'_tch`yr' & sib`k'==1 & year > `yr'
			replace lasthad_osp = "sib`s'" if ptch == sib`s'_tch`yr' & sib`k'==1 & year > `yr'
			replace lasthad_yrp = `yr' if ptch == sib`s'_tch`yr' & sib`k'==1 & year > `yr'
			replace lasthad_grp = grade_sib`s'_`yr' if ptch == sib`s'_tch`yr' & sib`k'==1 & year > `yr'
			replace lasthad_sincep = year - `yr' if ptch == sib`s'_tch`yr' & sib`k'==1 & year > `yr'
		}
		local diff = `diff' + 1
	}
	local c = `c' + 1
}


**Deal with multiple ptch having taught os**
sort lea_r schlcode_fl year grade mastid

egen id = group(lea_r schlcode_fl year grade mastid)

bys id: egen tot_ostch = count(any_ostchp)
tab tot_ostch

gen mult_ostch = (tot_ostch > 1)

bys id: egen multi_os = max(mult_ostch)

drop mult_ostch

bys id: egen recent_yr = max(lasthad_yrp)
replace recent_yr = . if tot_ostch == 1
replace recent_yr = . if family == 1 | family == .

replace any_ostchp = . if recent_yr != lasthad_yrp & multi_os == 1

bys id: egen tot_ostch2 = count(any_ostchp)
tab tot_ostch2

**Break ties: Sibling Closest in Age**
gen sibnum = .
forval k = 1/8 {
	replace sibnum = `k' if lasthad_osp == "sib`k'"
}

bys id: egen sib_num = max(sibnum)
drop sibnum

forval k = 1/8 {
	bys id: replace any_ostchp = . if tot_ostch2 >= 2 & sib_num == `k' & lasthad_osp != "sib`k'"
}

bys id: egen tot_ostch3 = count(any_ostchp)
tab tot_ostch3

drop multi_os id recent_yr tot_ostch tot_ostch2 tot_ostch3

sa "$data/panel_rr_1a.dta", replace

display c(current_time)

