clear all
version 12
set more off
cap log close
do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"


forvalues i=1995/2013{
	cd $raw
	cd Classroom
	cd Personnel
	use pers`i'.dta, clear
	keep teachid tch_sex tch_eth
	gen year = `i' 	
	cd $data
	save temp`i'.dta, replace
}

cd $data
use temp1995.dta, clear
forvalues i=1996/2013 {
	append using temp`i'.dta
	}

preserve	

drop year tch_sex
drop if teachid==.
duplicates drop

bys teachid: gen check = _n
tab check 
*flagging those teachers wi multiple different entry for race/sex
bys teachid: egen maxcheck = max(check)

cap drop flag_eth
gen flag_eth = 0
replace flag_eth = 1 if maxcheck > 1

*keeping the id and flag to merge back into dataset
keep teachid flag_eth
duplicates drop //isid teachid

cd $data
save "flag_eth.dta", replace

restore
*merging with flagged id to use the value that is more frequently seen for the diff characteristics for each person
merge m:1 teachid using "flag_eth.dta"
drop _merge

*there are multiple entry for the same year for each teacher
sort teachid year
quietly by teachid year: gen dup = cond(_N==1,0,_n)
drop if dup>1
drop dup

sort teachid year
bys teachid: gen ct_A = 1 if tch_eth=="A" & flag_eth==1
bys teachid: gen ct_B = 1 if tch_eth=="B" & flag_eth==1
bys teachid: gen ct_H = 1 if tch_eth=="H" & flag_eth==1
bys teachid: gen ct_I = 1 if tch_eth=="I" & flag_eth==1
bys teachid: gen ct_M = 1 if tch_eth=="M" & flag_eth==1
bys teachid: gen ct_N = 1 if tch_eth=="N" & flag_eth==1
bys teachid: gen ct_W = 1 if tch_eth=="W" & flag_eth==1

bys teachid ct_A: gen n_A = _N if ct_A==1 & flag_eth==1
bys teachid ct_B: gen n_B = _N if ct_B==1 & flag_eth==1
bys teachid ct_H: gen n_H = _N if ct_H==1 & flag_eth==1
bys teachid ct_I: gen n_I = _N if ct_I==1 & flag_eth==1
bys teachid ct_M: gen n_M = _N if ct_M==1 & flag_eth==1
bys teachid ct_N: gen n_N = _N if ct_N==1 & flag_eth==1
bys teachid ct_W: gen n_W = _N if ct_W==1 & flag_eth==1

bys teachid: egen N_A = max(n_A) if flag_eth==1
bys teachid: egen N_B = max(n_B) if flag_eth==1
bys teachid: egen N_H = max(n_H) if flag_eth==1
bys teachid: egen N_I = max(n_I) if flag_eth==1
bys teachid: egen N_M = max(n_M) if flag_eth==1
bys teachid: egen N_N = max(n_N) if flag_eth==1
bys teachid: egen N_W = max(n_W) if flag_eth==1

egen max_eth = rowmax(N_A N_B N_H N_I N_M N_N N_W)

gen Tteacheth = ""
bys teachid: replace Tteacheth = "A" if max_eth==n_A & flag_eth==1
bys teachid: replace Tteacheth = "B" if max_eth==n_B & flag_eth==1
bys teachid: replace Tteacheth = "H" if max_eth==n_H & flag_eth==1
bys teachid: replace Tteacheth = "I" if max_eth==n_I & flag_eth==1
bys teachid: replace Tteacheth = "M" if max_eth==n_M & flag_eth==1
bys teachid: replace Tteacheth = "N" if max_eth==n_N & flag_eth==1
bys teachid: replace Tteacheth = "W" if max_eth==n_W & flag_eth==1

*race that we see more than others
sort teachid Tteacheth
quietly by teachid Tteacheth: gen dup = cond(_N==1,0,_n)
drop if dup>1
drop if Tteacheth =="" & flag_eth==1
drop dup

*race that we see equally, take the later years
sort teachid year
bys teachid: gen check = _N
bys teachid: gen checkcheck = _n
gen teacheth = ""
replace teacheth = Tteacheth if check==checkcheck
drop if teacheth=="" & flag_eth==1
drop if teachid==.
replace teacheth=tch_eth if flag_eth==0

keep teachid tch_eth teacheth flag_eth

gen temp = .
replace temp = 1 if teacheth == "A"
replace temp = 2 if teacheth == "B"
replace temp = 3 if teacheth == "H"
replace temp = 4 if teacheth == "I"
replace temp = 5 if teacheth == "M"
replace temp = 6 if teacheth == "W"
drop teacheth
ren temp teacheth

label value teacheth teacheth
label define teacheth 1 "Asian" 2 "Black" 3 "Hispanic" 4 "Indian" 5 "Multi-racial" 6 "White"

cd $data
save teacher_eth.dta, replace //isid teachid

forvalues i=1995/2013 {
	erase temp`i'.dta
	}
	
erase flag_eth.dta


