

use "$work/cleaned_teach_exp_file.dta"

*clean up teacher education
bys teachid: egen educmax = max(educ_level)
bys teachid: egen educmin = min(educ_level)
g educmaxyr = year if educ_level==educmax
g educminyr = year if educ_level==educmin
bys teachid: egen educmin_maxyr = max(educminyr)
*educmin_maxyr is the last year we see you with the lowest ed
bys teachid: egen educmin_minyr = min(educminyr)
*educmin_minyr is the first year we see you with the lowest ed

bys teachid: egen educmax_minyr = min(educmaxyr)
*educmax_minyr is the first year we see you with the highest ed
bys teachid: egen educmax_maxyr = max(educmaxyr)
*educmax_maxyr is the last year we see you with the highest ed
*verified that educmin_yr and educmax_yr are correct. Only use these for cases where educmax!=educmin (for these its coded correctly)

g educmi = missing(educ_level)
bys teachid: egen anyeducmi = max(educmi)

count if educ_level==.
count if educ_level==. & educmax==educmin 
count if educ_level==. & educmax==educmin & educmax!=.

count if educmax_minyr==educmin_minyr & educmax==educmin & educmax_minyr!=. & educmin_minyr!=. 
count if educmax_minyr!=educmin_minyr & educmax==educmin & educmax_minyr!=. & educmin_minyr!=.

g educ_new = educ_level
replace educ_new= educmax if educmax==educmin & year>=educmax_minyr & educ_new==.
replace educ_new = educmin if year>educmin_minyr & year<educmax_minyr & educmin_minyr!=. & educmax_minyr!=. & educmax!=educmin & educ_new==.
*Replace educ with educmin if year is after the first yr we see you with lowest ed but before the first year we see you with highest ed
replace educ_new = educmax if year>=educmax_minyr & educmax_minyr!=. & educmax!=educmin & educ_new==.
*Replace educ with educmax if year is after the first yr we see you with highest ed 

g educ_imputed = educ_new!=. & educ_level==.

*nbpts
bys teachid: egen nbptsmax = max(nbpts)
bys teachid: egen nbptsmin = min(nbpts)
g nbptsmaxyr = year if nbpts==nbptsmax
g nbptsminyr = year if nbpts==nbptsmin
bys teachid: egen nbptsmin_maxyr = max(nbptsminyr)
*nbptsmin_maxyr is the last year we see you with the lowest ed
bys teachid: egen nbptsmin_minyr = min(nbptsminyr)
*nbptsmin_minyr is the first year we see you with the lowest ed


bys teachid: egen nbptsmax_minyr = min(nbptsmaxyr)
*nbptsmax_minyr is the first year we see you with the highest ed
bys teachid: egen nbptsmax_maxyr = max(nbptsmaxyr)
*nbptsmax_maxyr is the last year we see you with the highest ed
*verified that nbptsmin_yr and nbptsmax_yr are correct. Only use these for cases where nbptsmax!=nbptsmin 

g nbptsmi = missing(nbpts)
bys teachid: egen anynbptsmi = max(nbptsmi)

count if nbpts==.
count if nbpts==. & nbptsmax==nbptsmin 
count if nbpts==. & nbptsmax==nbptsmin & nbptsmax!=.

count if nbptsmax_minyr==nbptsmin_minyr & nbptsmax==nbptsmin & nbptsmax_minyr!=. & nbptsmin_minyr!=. 
count if nbptsmax_minyr!=nbptsmin_minyr & nbptsmax==nbptsmin & nbptsmax_minyr!=. & nbptsmin_minyr!=.
*This should be zero

g nbpts_imp = nbpts
replace nbpts_imp= nbptsmax if nbptsmax==nbptsmin & year>=nbptsmax_minyr & nbpts_imp==. /*Replace future missings of nbpts with your constant nbpts we see*/
replace nbpts_imp = nbptsmin if year>nbptsmin_minyr & year<nbptsmax_minyr & nbptsmin_minyr!=. & nbptsmax_minyr!=. & nbptsmax!=nbptsmin & nbpts_imp==.
*Replace nbpts with nbptsmin if year is after the first yr we see you with lowest ed but before the first year we see you with highest ed
replace nbpts_imp = nbptsmax if year>=nbptsmax_minyr & nbptsmax_minyr!=. & nbptsmax!=nbptsmin & nbpts_imp==.
*Replace nbpts with nbptsmax if year is after the first yr we see you with highest ed 

g nbpts_imputed = nbpts_imp!=. & nbpts==.

***********************
*For teacher experience, create flag that its imputed but not missing from pay code
g exp_is_imputed = exp_imputed==1 & missing_pay_data==0
bys teachid: egen exp_is_imputedw = max(exp_is_imputed)
drop educ_level nbpts
ren educ_new educ_level
ren nbpts_imp nbpts

g more_than_BA= educ_level>0 if educ_level!=.
g expgt3i = exp>=3 if exp!=.
g expgt5i =exp>=5 if exp!=.
g expgt10i =exp>=10 if exp!=.

drop if teachid==.
keep teachid year educ_level nbpts exp exp_is_imputedw exp_ever_imputed nbpts_imputed educ_imputed more_than_BA expgt3i expgt5i expgt10i
sort teachid year
cd "$data"
sa teach_exp_file.dta, replace
