clear all
version 12
set more off
cap log close

do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

/*
This do-file creates the final data set to be used for all simulations and regressions.
It adds necessary additional variables, as well as drops those variables that are no longer needed.
*/

cd "$data"
use panel2_rr_1a.dta, clear

****Keep only variables being used****
keep lea_r schlcode_fl grade year mastid ptch atch any_ostchp real_match propst_1a preread va* tch_num n_tch eds White Black Hispanic Other expgt3i more_than_BA nbpts tch_rblack sib* lasthad_yrp lasthad_osp agegap_s* lasthad_sincep schgryr has_samertmt

**Create Simulation Variables**
rename propst_1a propst

egen kid_obs = tag(lea_r schlcode_fl grade year mastid)
replace kid_obs = . if kid_obs == 0

sort lea_r schlcode_fl grade year mastid ptch

bys lea_r schlcode_fl grade year mastid: gen cumul_propst = sum(propst)
bys lea_r schlcode_fl grade year mastid: gen lag_cumul_propst = cumul_propst[_n-1]
replace lag_cumul_propst = 0 if lag_cumul_propst == .

bys grade: egen preread_md = median(preread)
gen preread_gtm = (preread > preread_md)
replace preread_gtm = . if preread == .

egen va_mn = mean(va)
gen va_gtm = (va > va_mn) if va !=.


*Share FRL distribution
bys lea_r schlcode_fl: egen share_eds = mean(eds)
lab var share_eds "Share of students in school (all years) on FRL"

xtile share_eds_md = share_eds, nq(2)
lab var share_eds_md "Indicates which half of Share FRL distribution school is in"
lab define med 1 "Below median - Rich" 2 "Above median - Poor"
lab val share_eds_md med

xtile share_eds_terc = share_eds, nq(3)
lab var share_eds_terc "Indicates which tercile of Share FRL distribution school is in"
lab define terc 1 "First Tercile - Rich" 2 "Second Tercile - Middle" 3 "Third Tercile - Poor"
lab val share_eds_terc terc

gen rich_schl = (share_eds_md == 1)

**Create Regression Variables**
replace any_ostchp = 0 if any_ostchp==.
lab var any_ostchp "Any OS had tchr prev"

egen schgryrst = group(lea_r schlcode_fl grade year any_ostchp)

g nw = 1 - White
g preread_ltm = 1 - preread_gtm

*unique child-yr identifier
egen my = group(mastid year)
xtset my ptch

*Interactions
foreach var in eds preread preread_gtm Black Hispanic Other expgt3i more_than_BA nbpts va va_gtm nw preread_ltm rich_schl {
g st_`var' = any_ostchp*`var'
}
foreach var in expgt3i more_than_BA nbpts va va_gtm {
g eds_`var' = eds*`var'
g nw_`var' = nw*`var'
g la_`var' = preread_ltm*`var'
g seds_`var' = any_ostchp*eds_`var'
g snw_`var' = any_ostchp*nw_`var'
g sla_`var' = any_ostchp*la_`var'
}
foreach var in eds va_gtm va {
gen rich_`var' = rich_schl*`var'
gen st_rich_`var' = any_ostchp*rich_`var'
}

gen st_eds_va_gtm = st_eds*va_gtm
gen st_rich_eds_va_gtm = st_rich_eds*va_gtm

gen st_eds_va = st_eds*va
gen st_rich_eds_va = st_rich_eds*va

**Create OS Lagged Score Variable**
gen lagscore_fs = .
lab var lagscore_fs "Focal OS lagged reading score"

local c = 2
while `c' < 9 {
	local dif = 1
	forval k = `c'/8 {
		forval yr = 2007/2012 {
			local s = `k' - `dif'
			display "OS `s', YS `k', Year `yr'"
			replace lagscore_fs = sib`s'_preread`yr' if lasthad_yrp == `yr' & lasthad_osp == "sib`s'" & any_ostchp == 1
		}
		local dif = `dif' + 1
	}
	local c = `c' + 1
}

replace lagscore_fs = 0 if lagscore_fs == . & any_ostchp != 1
replace lagscore_fs = 9999999 if lagscore_fs == . & any_ostchp == 1
bys lea_r schlcode_fl grade year mastid: egen maxlag = max(lagscore_fs) if lagscore_fs >= 0
bys lea_r schlcode_fl grade year mastid: egen minlag = min(lagscore_fs) if lagscore_fs <= 0
replace lagscore_fs = maxlag if lagscore_fs >= 0
replace minlag = . if minlag == 0
replace lagscore_fs = minlag if minlag != .
replace lagscore_fs = . if lagscore_fs == 9999999
drop maxlag minlag

**Create OS Reading Score Gain Variable**
gen rgain_fs = .
lab var rgain_fs "Focal OS gain in reading score"

local c = 2
while `c' < 9 {
	local dif = 1
	forval k = `c'/8 {
		forval yr = 2007/2012 {
			local s = `k' - `dif'
			display "OS `s', YS `k', Year `yr'"
			replace rgain_fs = sib`s'_rgain`yr' if lasthad_yrp == `yr' & lasthad_osp == "sib`s'" & any_ostchp == 1
		}
		local dif = `dif' + 1
	}
	local c = `c' + 1
}

replace rgain_fs = 0 if rgain_fs == . & any_ostchp != 1
replace rgain_fs = 9999999 if rgain_fs == . & any_ostchp == 1
bys lea_r schlcode_fl grade year mastid: egen maxgain = max(rgain_fs) if rgain_fs >= 0
bys lea_r schlcode_fl grade year mastid: egen mingain = min(rgain_fs) if rgain_fs <= 0
replace rgain_fs = maxgain if rgain_fs >= 0
replace mingain = . if mingain == 0
replace rgain_fs = mingain if mingain != .
replace rgain_fs = . if rgain_fs == 9999999
drop maxgain mingain


**Create Indicator for Focal OS had Teacher more than once**
gen byte multiyrs_ptch = .
lab var multiyrs_ptch "Focal OS had teacher in multiple years"

forval s = 1/8 {
	forval yr = 2007/2011 {
		forval t = 2008/2012 {
			display "OS `s', Year `yr', Comp Year `t'"
			replace multiyrs_ptch = 1 if lasthad_osp == "sib`s'" & sib`s'_tch`yr' == sib`s'_tch`t' & `yr' < `t' & (sib`s'_tch`yr' == ptch | sib`s'_tch`t' == ptch) & lasthad_osp == "sib`s'" & any_ostchp == 1
		}
	}
}

replace multiyrs_ptch = 0 if multiyrs_ptch == . & any_ostchp == 1
bys lea_r schlcode_fl grade year mastid: egen maxmult = max(multiyrs_ptch)
replace multiyrs_ptch = maxmult
replace multiyrs_ptch = 0 if multiyrs_ptch == .
drop maxmult


**Create variable for gap in YS and Focal OS lagged reading score**
gen scoregap = .
lab var scoregap "Difference in YS and focal OS lagged reading score"

local c = 2
while `c' < 9 {
	local dif = 1
	forval k = `c'/8 {
		forval yr = 2007/2012 {
			local s = `k' - `dif'
			display "OS `s', YS `k', Year `yr'"
			replace scoregap = abs(preread - sib`s'_preread`yr') if lasthad_yrp == `yr' & lasthad_osp == "sib`s'" & any_ostchp == 1
		}
		local dif = `dif' + 1
	}
	local c = `c' + 1
}

replace scoregap = 0 if scoregap == . & any_ostchp != 1
replace scoregap = 9999999 if scoregap == . & any_ostchp == 1
bys lea_r schlcode_fl grade year mastid: egen maxgap = max(scoregap)
replace scoregap = maxgap
replace scoregap = . if scoregap == 9999999
drop maxgap

**Create Race interaction**
gen black_int = Black*tch_rblack
lab var black_int "Interaction with Black and Teacher is Black"


**Create Age Gap with focal OS**
gen agegap_fs = .
lab var agegap_fs "Age Gap between YS and focal OS"

local c = 2
while `c' < 9 {
	local dif = 1
	forval k = `c'/8 {
		local s = `k' - `dif'
		display "OS `s', YS `k'"
		replace agegap_fs = agegap_s`s's`k' if lasthad_osp == "sib`s'" & sib`k' == 1 & any_ostchp == 1
		local dif = `dif' + 1
	}
	local c = `c' + 1
}

replace agegap_fs = 0 if agegap_fs == . & any_ostchp != 1
replace agegap_fs = 9999999 if agegap_fs == . & any_ostchp == 1
bys lea_r schlcode_fl grade year mastid: egen maxage = max(agegap_fs)
replace agegap_fs = maxage
replace agegap_fs = . if agegap_fs == 9999999
drop maxage

**Create indicators that focal OS had teacher more than two years ago**
gen byte long_time = (lasthad_sincep > 2) if any_ostchp == 1
lab var long_time "More than 2 years since Focal OS had teacher"

replace long_time = 0 if long_time == . & any_ostchp != 1
replace long_time = 9 if long_time == . & any_ostchp == 1
bys lea_r schlcode_fl grade year mastid: egen maxtime = max(long_time)
replace long_time = maxtime
replace long_time = . if long_time == 9
drop maxtime

foreach var in rgain_fs lagscore_fs multiyrs_ptch scoregap black_int agegap_fs long_time tch_rblack {
	gen st_`var' = any_ostchp*`var'
}

drop lasthad_yrp lasthad_osp sib* agegap_s* lasthad_sincep

**Create School IDs**
sort lea_r schlcode_fl year
egen schlID = group(lea_r schlcode_fl)
egen schlyrID = group(lea_r schlcode_fl year)

***Additional Variables***
xtile pct = va, n(100)

g va25t50 = pct>25 & pct<=50 
g va50t75 = pct>50 & pct<=75
g va75p = pct>=75 & pct!=.

g eds_va25t50 = eds*va25t50
g eds_va50t75 = eds*va50t75
g eds_va75p = eds*va75p

g st_va25t50 = any_ostchp*va25t50
g st_va50t75 = any_ostchp*va50t75
g st_va75p = any_ostchp*va75p

g seds_va25t50  = any_ostchp*eds*va25t50
g seds_va50t75  = any_ostchp*eds*va50t75
g seds_va75p  = any_ostchp*eds*va75p 

save "$data/final_1a.dta", replace

