clear all
version 13
set more off
do "/home/home2/qureshi_rs1/teacher_sorting/directory_do"

/* 
	INPUT:  01_math_read_classes.dta
		disability.dta
		controls_VAM.dta
	OUTPUT: 
	VAM_data.dta
*/
cd $data
use 01_math_read_classes.dta

*Dropping unnecessary varaibles
drop semester collection_code dup6a dup7b inter num_courses ///
     stud_yr xmath xread mcrs_num has_mult_m rcrs_num has_mult_r ///
     mc_course nmc_course mc_num_course diff_MC_crsid rc_course ///
     nrc_course rc_num_course diff_RC_crsid mteach_cc rteach_cc ///
     my_course nmy_course my_num_course ry_course nry_course    ///
     ry_num_course ms_course nms_course ms_num_course rs_course ///
     nrs_course rs_num_course diff_math_sem_crsid diff_MS_crsid ///
     diff_read_sem_crsid diff_RS_crsid kid_yr mt_course nmt_course ///
     mt_num_course rt_course nrt_course rt_num_course              ///
     mteach_switch_sem mteach_sm rteach_switch_sem rteach_sm       ///
     ms_kid_yr rs_kid_yr fall xfall min_sem fall_first_sem 	   ///
     mm_course rr_course mmcou_num mmcrs_num has_mult_mm rrcou_num ///
     rrcrs_num has_mult_rr m_course r_course mst_course mst_num_course ///
     nmst_course rst_course nrst_course rst_num_course mteach_switchcrs ///
     mteach_crs rteach_switchcrs rteach_crs mkid_moret rkid_moret ///
     math_course_switch_drop ma_crs_sw_dp read_course_switch_drop ///
     rd_crs_sw_dp mteach_yr rteach_yr num_math_teach_yr xnum_math_teach_yr ///
     num_read_teach_yr xnum_read_teach_yr mclass_yr num_math_crs_yr ///
     xnum_math_crs_yr rclass_yr num_read_crs_yr xnum_read_crs_yr ///
     kid_m_fyr kid_r_fyr kid_m_mm_swt kid_r_rr_swt mult_read_class ///
     kid_mr_nt mult_read_teacher mult_math_class mult_math_teacher ///
     math_m_class rnum_courses 

***********************************
*picking main courses for students
***********************************
*multiple if taking more than one course code
bysort math_subj mastid year subject_id : gen mm_course=_n if math_subj==1
bysort read_subj mastid year subject_id : gen rr_course=_n if read_subj==1

egen mmcou_num  =total(mm_course) if mm_course==1 & math_subj==1, by(mastid year)
egen mmcrs_num  =max(mmcou_num)   if math_subj==1, by(mastid year)
gen  has_mult_mm=(mmcrs_num>1)    if math_subj==1 & !missing(mmcrs_num)

egen rrcou_num  =total(rr_course) if rr_course==1 & read_subj==1, by(mastid year)
egen rrcrs_num  =max(rrcou_num)   if read_subj==1, by(mastid year)
gen  has_mult_rr=(rrcrs_num>1)    if read_subj==1 & !missing(rrcrs_num)

bysort math_subj mastid year: gen m_course=_n if math_subj==1
bysort read_subj mastid year: gen r_course=_n if read_subj==1

tab has_mult_mm if m_course==1
tab has_mult_rr if r_course==1		

tab subject if has_mult_mm==1 & math_subj==1, m
tab subject if has_mult_rr==1 & read_subj==1, m

gen prim_math    =(subject=="math (k-8)")  if math_subj==1 & has_mult_mm==1
egen mathk8      =max(prim_math)           if math_subj==1 & has_mult_mm==1,by(mastid year)
replace prim_math=1                        if subject=="other math topics" & prim_math==0 & mathk8==0  
drop if prim_math==0 

gen prim_read    =(subject=="language arts") if read_subj==1 & has_mult_rr==1
egen langart     =max(prim_read)             if read_subj==1 & has_mult_rr==1, by(mastid year)
replace prim_read=1			     if subject=="reading" & prim_read==0 & langart==0
drop if prim_read==0

drop mm_course rr_course mmcou_num mmcrs_num has_mult_mm rrcou_num ///
     rrcrs_num has_mult_rr m_course r_course prim_math mathk8      ///
     prim_read langart

*section switchers
duplicates tag mastid lea_r schlcode_fl year grade coursetitle if math_subj==1, gen(mult_sec_m)
duplicates tag mastid lea_r schlcode_fl year grade coursetitle if read_subj==1, gen(mult_sec_r)

gen switcher_math= (mult_sec_m>0 & math_subj==1)
gen switcher_read= (mult_sec_r>0 & read_subj==1)

egen sec_switch_math=max(switcher_math) if math_subj==1, by(mastid year)
egen sec_switch_read=max(switcher_read) if read_subj==1, by(mastid year)

bysort  math_subj middle_sch mastid year: gen kid_m_middle=_n if math_subj==1 & middle_sch==1
bysort  math_subj middle_sch mastid year: gen kid_m_elem=_n if math_subj==1 & middle_sch==0

bysort  read_subj middle_sch mastid year: gen kid_r_middle=_n if read_subj==1  & middle_sch==1
bysort  read_subj middle_sch mastid year: gen kid_r_elem=_n if read_subj==1  & middle_sch==0


tab sec_switch_math if kid_m_middle==1
tab sec_switch_math if kid_m_elem==1

tab sec_switch_read if kid_r_middle==1
tab sec_switch_read if kid_r_elem==1

drop if sec_switch_math==1
drop if sec_switch_read==1

drop mult_sec_m mult_sec_r switcher_math switcher_read sec_switch_math ///
     sec_switch_read kid_m_middle kid_m_elem kid_r_middle kid_r_elem

*Merge in disability file
cd $data
sort mastid year
merge m:1 mastid year using disability.dta
keep if _merge==3
drop    _merge


*class size
bysort lea schlcode year coursetitle section mastid:gen cnt_stud_cl=_n
egen totalkids =total(cnt_stud_cl)               if cnt_stud_cl==1, by(lea schlcode year coursetitle section)
egen class_size=max(totalkids), by(lea schlcode year coursetitle section)

*class identified at coursetitle section and teacher)
bysort lea schlcode year coursetitle section teachid mastid:gen cnt_stud_cl1=_n
egen totalkids1  =total(cnt_stud_cl1)            if cnt_stud_cl1==1, by(lea schlcode year coursetitle section teachid)
egen class_size_t=max(totalkids1), by(lea schlcode year coursetitle section teachid)

bys math_subj mastid year coursetitle section: gen nmath_cl=_n if math_subj==1
bys read_subj mastid year coursetitle section: gen nread_cl=_n if read_subj==1
egen   num_math_crs_yr=total(nmath_cl) if math_subj==1 & nmath_cl==1, by(mastid year)
egen  xnum_math_crs_yr= max(num_math_crs_yr) if math_subj==1, by(mastid year)

gen mult_math= (xnum_math_crs_yr>1) if math_subj==1

egen   num_read_crs_yr=total(nread_cl) if  read_subj==1 & nread_cl==1, by(mastid year)
egen  xnum_read_crs_yr=max(num_read_crs) if read_subj==1, by(mastid year)

gen mult_read=(xnum_read_crs_yr>1) if read_subj==1


bysort  math_subj middle_sch mastid year: gen kid_m_middle=_n if math_subj==1 & middle_sch==1
bysort  math_subj middle_sch mastid year: gen kid_m_elem=_n if math_subj==1 & middle_sch==0

bysort  read_subj middle_sch mastid year: gen kid_r_middle=_n if read_subj==1  & middle_sch==1
bysort  read_subj middle_sch mastid year: gen kid_r_elem=_n if read_subj==1  & middle_sch==0

tab mult_math if kid_m_middle==1
tab mult_math if kid_m_elem==1

tab mult_read if kid_r_middle==1
tab mult_read if kid_r_elem==1
cd $data
save math_read_multiple_class.dta, replace

drop nread_cl num_math_crs_yr xnum_math_crs_yr num_read_crs_yr xnum_read_crs_yr ///
     kid_m_middle kid_m_middle kid_m_elem kid_r_middle kid_r_elem
     
*Merge in other covariates
cd $data
sort mastid year lea_r schlcode_fl grade
merge m:1 mastid year lea_r schlcode_fl grade using controls_VAM.dta
ren _merge _merge_class_to_controls_data
cd $data
save math_read_controls_multiple_class.dta, replace

cap drop mult_read mult_math nmath_cl
egen mod_grade=mode(grade), min by(lea_r schlcode_fl year coursetitle section teachid)

keep if grade==3
cd $data
save grade3.dta, replace
*-8 graders
cd $data
use math_read_controls_multiple_class.dta, clear

cap drop mult_read mult_math nmath_cl
egen mod_grade=mode(grade), min by(lea_r schlcode_fl year coursetitle section teachid)
drop if grade==3
bysort mastid year lea_r schlcode_fl mod_grade: gen stud_yr_modgr=_n

foreach x of var preread premath{

	egen meansgy_`x'=mean(`x')         if `x'!=. & stud_yr_modgr==1, by(lea_r schlcode_fl mod_grade year)
	egen SGY_`x'    =max(meansgy_`x')  if `x'!=., by(lea_r schlcode_fl mod_grade year)
	}

foreach x of var preread premath{
	g SGY_`x'2= SGY_`x'^2
	g SGY_`x'3= SGY_`x'^3
	}
xi i.mod_grade|SGY_premath i.mod_grade|SGY_premath2 i.mod_grade|SGY_premath3, prefix(SGMA)
xi i.mod_grade|SGY_preread i.mod_grade|SGY_preread2 i.mod_grade|SGY_preread3, prefix(SGRD)  	

drop meansgy_preread meansgy_premath stud_yr_modgr SGMAmod_gra_5 SGMAmod_gra_6 SGMAmod_gra_7 ///
     SGMAmod_gra_8 SGRDmod_gra_5 SGRDmod_gra_6 SGRDmod_gra_7 SGRDmod_gra_8
*class-level covariates
global listcontrols Black White Hispanic Other Female disabled Age eds lep_flag grade_repeat

foreach x of var $listcontrols premath preread{
	
	egen CL_`x'=mean(`x') if `x'!=., by(lea_r schlcode_fl year coursetitle section teachid)
	
	}
	
foreach x in premath preread{
	g CL_`x'2=CL_`x'^2
	g CL_`x'3=CL_`x'^3
	}
xi i.mod_grade|CL_premath i.mod_grade|CL_premath2 i.mod_grade|CL_premath3, prefix(CLMA)
xi i.mod_grade|CL_preread i.mod_grade|CL_preread2 i.mod_grade|CL_preread3, prefix(CLRD)  	

drop CLMAmod_gra_5 CLMAmod_gra_6 CLMAmod_gra_7 CLMAmod_gra_8 CLRDmod_gra_5 CLRDmod_gra_6 ///
     CLRDmod_gra_7 CLRDmod_gra_8 
     
egen class_id=group(lea_r schlcode_fl year coursetitle section teachid)  

bys math_subj mastid year: gen nmath_cl=_N if math_subj==1
bys read_subj mastid year: gen nread_cl=_N if read_subj==1

gen multiple_math= (nmath_cl>1 & math_subj==1) if math_subj==1
gen multiple_read= (nread_cl>1 & read_subj==1) if read_subj==1



egen   num_math_crs_yr=total(nmath_cl)       if math_subj==1, by(mastid year)

egen   min_class_size_math= min(class_size_t) if math_subj==1, by(mastid year)
egen   max_class_size_math= max(class_size_t) if math_subj==1, by(mastid year)

egen   min_class_math_pretest=min(CL_premath) if math_subj==1, by(mastid year)
egen   max_class_math_pretest=max(CL_premath) if math_subj==1, by(mastid year) 

count if min_class_size_math==max_class_size_math & nmath_cl==2
count if min_class_math_pretest==max_class_math_pretest & nmath_cl==2 & min_class_math_pretest!=.


bys math_subj mastid year: gen math_n=_n if math_subj==1
egen   num_read_crs_yr=total(nread_cl)   if read_subj==1, by(mastid year)
egen   min_class_size_read= min(class_size_t) if read_subj==1, by(mastid year)
egen   max_class_size_read= max(class_size_t) if read_subj==1, by(mastid year)
egen   min_class_read_pretest=min(CL_preread) if read_subj==1, by(mastid year)
egen   max_class_read_pretest=max(CL_preread) if read_subj==1, by(mastid year) 
count if min_class_size_read==max_class_size_read & nread_cl==2
count if min_class_read_pretest==max_class_read_pretest & nread_cl==2 & min_class_read_pretest!=.

drop num_math_crs_yr min_class_size_math max_class_size_math min_class_math_pretest ///
     max_class_math_pretest math_n num_read_crs_yr min_class_size_read ///
     max_class_size_read min_class_read_pretest max_class_read_pretest
         
cd $data
save VAM_data.dta, replace 

append using grade3.dta

drop _merge

cd $data
save VAM_data.dta, replace 
